<?php
// OAR Drawgantt SVG version - main page + navigation toolbox

////////////////////////////////////////////////////////////////////////////////////////////////////
// Configuration: DO NOT EDIT HERE. Customization must go in /etc/oar/drawgantt-config.inc.php
////////////////////////////////////////////////////////////////////////////////////////////////////

$CONF=array();
$CONF['nav_filters'] = array(
  'all clusters' => "",
  'cluster1 only' => 'cluster="cluster1"',
  'cluster2 only' => 'cluster="cluster2"',
  'cluster3 only' => 'cluster="cluster3"',
);
$CONF['nav_timezones'] = array(
  'UTC' => "UTC",
  'Paris' => "Europe/Paris",
);
$CONF['nav_custom_buttons'] = array(
  'my label' => 'http://my.url'
);

// Overwrite configuration with values from drawgantt-config.inc.php
define('CONFIG_DIR', '/etc/oar');
define('CONFIG_FILE', CONFIG_DIR . '/drawgantt-config.inc.php');
if (is_readable(CONFIG_FILE)) {
    require CONFIG_FILE;
}

$filter = array_key_exists('filter',$_GET)?$_GET['filter']:key($CONF['nav_filters']);
$timezone = array_key_exists('timezone',$_GET)?$_GET['timezone']:key($CONF['nav_timezones']);


$output = <<<EOT
<!DOCTYPE html>
<html>
  <head>
<meta name="viewport" content="initial-scale=1.0, user-scalable=no" />
<meta http-equiv="content-type" content="text/html; charset=UTF-8"/>
<title>OAR Drawgantt SVG</title>
<style>
  body {
    background-color: white;
  }
  #panel {
    position: absolute;
    background-color: lightgrey;
    top: 0px;
    left: 0px;
    width: 100%;
    z-index: 1;
    opacity: 1;
  }
  #svgObj {
    position: absolute;
    top: 0px;
    left: 0px;
    z-index: 0;
    margin: 0px;
  }
  #waiter {
    position: absolute;
    background-color: lightgreen;
    bottom: 10px;
    visibility: hidden;
    z-index: 2;  
  }
</style>
<script type="text/javascript">
  window.addEventListener("scroll", show_panel, false);
  window.addEventListener("resize", reload_content, false);
  var relative_start = -86400;
  var relative_stop = 86400;
  var zoom_relative_start = 0;
  var zoom_relative_stop = 0;
  var filterSQL = "";
  var timezoneSQL = "";
  var scrolledX=0;
  var scrolledY=0;
  function sleep(millis, callback) {
    setTimeout(function() { callback(); } , millis);
  }
  function show_panel() {
    var panelDiv=document.getElementById("panel");
    panelDiv.style.top = window.scrollY + "px";
    panelDiv.style.left = window.scrollX + "px";
  }
  function reset() {
    relative_start = -86400;
    relative_stop = 86400;
    reload_content();
  }
  function shift(time) {
    relative_start += time;
    relative_stop += time;
    reload_content();
  }
  function next() {
    var t = relative_stop + (relative_stop - relative_start);
    relative_start = relative_stop;
    relative_stop = t;
    reload_content();
  }
  function prev() {
    var t = relative_start - (relative_stop - relative_start);
    relative_stop = relative_start;
    relative_start = t;
    reload_content();
  }
  function zoomin() {
    var t = relative_start + (relative_stop - relative_start) / 4;
    relative_stop = relative_stop - (relative_stop - relative_start) / 4;
    relative_start = t;
    reload_content();
  }
  function zoomout() {
    var t = (relative_stop - relative_start)/2;
    relative_stop += t;
    relative_start -= t;
    reload_content();
  }
  function set_zoom_window(now, start, stop) {
    zoom_relative_start = start - now;
    zoom_relative_stop = stop - now;
  }
  function zoom() {
    if (zoom_relative_start != zoom_relative_stop) {
      relative_start = zoom_relative_start;
      relative_stop = zoom_relative_stop;
      reload_content();
    }
  }
  function reload_content() {
    scrolledX = window.scrollX;
    scrolledY = window.scrollY;
    show_panel();
    var svgObj=document.getElementById("svgObj");
    var newURL= "drawgantt-svg.php?width=" + (window.innerWidth - 50)  + "&relative_start=" + relative_start + "&relative_stop=" + relative_stop + ((filterSQL)?"&filter=" + filterSQL:"") + ((timezoneSQL)?"&timezone=" + timezoneSQL:"");
    svgObj.data = newURL;
    svgObj.innerHTML = newURL;
    document.getElementById("waiter").style.visibility="visible";
  }
  function select_filter(reload) {
    var filterSelect=document.getElementById("filterSelect");
    filterSQL = filterSelect.value;
    window.scrollTo(0,0);
    reload && reload_content();
  }
  function select_timezone(reload) {
    var timezoneSelect=document.getElementById("timezoneSelect");
    timezoneSQL = timezoneSelect.value;
    window.scrollTo(0,0);
    reload && reload_content();
  }
  function openURL(url) {
    window.open(url);
  }
  function restore_scrolling() {
    window.scrollTo(scrolledX,scrolledY);
	document.getElementById("waiter").style.visibility="hidden";
  }
  function init() {
    show_panel();
    select_filter(false);
    select_timezone(false);
    sleep(100, reload_content);
  }
</script>
</head>
<body onload="init()">
<div id="panel" align="center">
EOT;
if (count($CONF['nav_filters']) > 1) {
  $output .= <<<EOT
<select id="filterSelect" onchange="select_filter(true)">
EOT;
  foreach ($CONF['nav_filters'] as $key => $value) {
    $output .= "<option " . (($key == $filter)?"selected ":"") . "value=\"$value\">$key</option>\n";
  }
  $output .= <<<EOT
</select>
EOT;
}
$output .= <<<EOT
<button type="button" onclick="shift(-604800)">&lt;1w</button>
<button type="button" onclick="shift(-86400)">&lt;1d</button>
<button type="button" onclick="shift(-21600)">&lt;6h</button>
<button type="button" onclick="shift(-3600)">&lt;1h</button>
<button type="button" onclick="prev()">&lt;&lt;</button>
<button type="button" onclick="zoomout()">-</button>
<button type="button" onclick="zoom()">zoom</button>
<button type="button" onclick="zoomin()">+</button>
<button type="button" onclick="next()">&gt;&gt;</button>
<button type="button" onclick="shift(3600)">&gt;1h</button>
<button type="button" onclick="shift(21600)">&gt;6h</button>
<button type="button" onclick="shift(86400)">&gt;1d</button>
<button type="button" onclick="shift(604800)">&gt;1w</button>
<button type="button" onclick="reload_content()">reload</button>
<button type="button" onclick="reset()">reset</button>

EOT;
if (count($CONF['nav_timezones']) > 1) {
  $output .= <<<EOT
<select id="timezoneSelect" onchange="select_timezone(true)">
EOT;
  foreach ($CONF['nav_timezones'] as $key => $value) {
    $output .= "<option " . (($key == $timezone)?"selected ":"") . "value=\"$value\">$key</option>\n";
  }
  $output .= <<<EOT
</select>
EOT;
}
foreach ($CONF['nav_custom_buttons'] as $key => $value) {
  $output .= "<button tupe=\"button\" onclick=\"openURL('$value')\">$key</button>\n";
}
$output .= <<<EOT
</div>
<object id="svgObj" type="image/svg+xml" data="" onload="restore_scrolling()"></object>
<div id="waiter">Processing data... please wait...</div>
</body>
</html>
EOT;
print $output;
